:orphan:

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _releasenotes:

FileBrowser 3.5 Release Notes
=============================

FileBrowser 3.5 is compatible with Django 1.4/1.5/1.6/1.7 as well as Grappelli 2.4/2.5/2.6.

Update from FileBrowser 3.4.x
-----------------------------

* Update Django to 1.4/1.5/1.6/1.7 and check https://docs.djangoproject.com/en/dev/releases/1.4/ or https://docs.djangoproject.com/en/dev/releases/1.5/ or https://docs.djangoproject.com/en/dev/releases/1.6/
* Update Grappelli to 2.4.x/2.5.x/2.6.x
* Update FileBrowser to 3.5.x